
#' Persistent configuration for R packages
#'
#' This package is meant to be used in other packages, and provides
#' configuration options for them.
#'
#' It is currently very minimal, and has two main functions: one
#' for setting configuration options (\code{\link{set_config}}), and one
#' for querying them (\code{\link{get_config}}).
#'
#' @docType package
#' @name pkgconfig-package
NULL
